Index: configure.in
===================================================================
RCS file: /cvs/kaffe/kaffe/configure.in,v
retrieving revision 1.201
diff -u -r1.201 configure.in
--- configure.in	2 Jun 2003 05:57:00 -0000	1.201
+++ configure.in	2 Jun 2003 07:33:54 -0000
@@ -873,6 +873,30 @@
 AC_C_CONST
 AC_C_INLINE
 
+AC_CACHE_CHECK(for struct in6_addr, ac_cv_struct_in6_addr,
+[AC_TRY_COMPILE([
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>],[
+struct in6_addr;
+], [ac_cv_struct_in6_addr=yes], [ac_cv_struct_in6addr=no])])
+if test "$ac_cv_struct_in6_addr" = yes; then
+    AC_DEFINE(HAVE_STRUCT_IN6_ADDR, 1,
+[Define if <netinet/in.h> defines 'struct in6_addr'])
+fi
+
+AC_CACHE_CHECK(for struct sockaddr_in6, ac_cv_struct_sockaddr_in6,
+[AC_TRY_COMPILE([
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>],[
+struct sockaddr_in6 address;
+], [ac_cv_struct_sockaddr_in6=yes], [ac_cv_struct_sockaddr_in6=no])])
+if test "$ac_cv_struct_sockaddr_in6" = yes; then
+    AC_DEFINE(HAVE_STRUCT_SOCKADDR_IN6, 1,
+[Define if <netinet/in.h> defines 'struct sockaddr_in6'])
+fi
+
 dnl =========================================================================
 dnl Check for [u]int{8,16,32,64} and bool.
 dnl -------------------------------------------------------------------------
@@ -959,6 +983,7 @@
 AC_CHECK_FUNCS([getcwd chdir getwd gettimeofday ftime time uname getuid])
 AC_CHECK_FUNCS([localtime])
 AC_CHECK_FUNCS([getaddrinfo])
+AC_CHECK_FUNCS([getnameinfo])
 
 AM_ICONV
 LIBS="$LIBS $LIBICONV"
Index: include/nets.h
===================================================================
RCS file: /cvs/kaffe/kaffe/include/nets.h,v
retrieving revision 1.5
diff -u -r1.5 nets.h
--- include/nets.h	6 Jan 2003 17:14:18 -0000	1.5
+++ include/nets.h	2 Jun 2003 07:33:54 -0000
@@ -13,7 +13,15 @@
 
 #include "config.h"
 #include "config-mem.h"
+#include "config-net.h"
 #include <errno.h>
+
+/* define a macro that's true iff IPv6 is fully supported */
+#if defined(AF_INET6) && defined(PF_INET6) && defined(HAVE_STRUCT_IN6_ADDR) && defined(HAVE_STRUCT_SOCKADDR_IN6)
+#define KAFFE_INET6
+#else
+#undef KAFFE_INET6
+#endif
 
 /* some systems define this already as a macro, in which we leave it as is */
 #ifndef h_errno
Index: libraries/clib/net/InetAddressImpl.c
===================================================================
RCS file: /cvs/kaffe/kaffe/libraries/clib/net/InetAddressImpl.c,v
retrieving revision 1.13
diff -u -r1.13 InetAddressImpl.c
--- libraries/clib/net/InetAddressImpl.c	15 May 2003 15:03:16 -0000	1.13
+++ libraries/clib/net/InetAddressImpl.c	2 Jun 2003 07:33:54 -0000
@@ -48,7 +48,7 @@
 	case java_net_InetAddressImpl_INET_ADDRESS_V4:
 		retval = AF_INET;
 		break;
-#if defined(AF_INET6)
+#if defined(KAFFE_INET6)
 	case java_net_InetAddressImpl_INET_ADDRESS_V6:
 		retval = AF_INET6;
 		break;
@@ -114,7 +114,7 @@
 				       sizeof(ia));
 			}
 		}
-#if defined(AF_INET6)
+#if defined(KAFFE_INET6)
 		if( retval == NULL )
 		{
 			struct in6_addr ia;
@@ -176,7 +176,7 @@
 			switch( curr->ai_family )
 			{
 			case PF_INET:
-#if defined(PF_INET6)
+#if defined(KAFFE_INET6)
 			case PF_INET6:
 #endif
 				count += 1;
@@ -190,7 +190,7 @@
 		curr = ai;
 		while( curr && retval )
 		{
-#if defined(PF_INET6)
+#if defined(KAFFE_INET6)
 			struct sockaddr_in6 *in6;
 #endif
 			struct sockaddr_in *in4;
@@ -216,7 +216,7 @@
 					retval = 0;
 				}
 				break;
-#if defined(PF_INET6)
+#if defined(KAFFE_INET6)
 			case PF_INET6:
 				in6 = (struct sockaddr_in6 *)
 					curr->ai_addr;
@@ -369,9 +369,9 @@
 struct Hjava_lang_String*
 java_net_NativeInetAddressImpl_getHostByAddr0(struct Hjava_net_NativeInetAddressImpl* none, HArrayOfByte *addr)
 {
-#if defined(HAVE_GETADDRINFO)
+#if defined(HAVE_GETNAMEINFO)
 	struct Hjava_lang_String *retval = 0;
-#if defined(AF_INET6)
+#if defined(KAFFE_INET6)
 	struct sockaddr_in6 sa_buf;
 	struct sockaddr_in6 *sin6 = &sa_buf;
 #else
@@ -397,7 +397,7 @@
 		sin->sin_port = 0;
 		memcpy(&sin->sin_addr, unhand_byte_array(addr), addr->length);
 		break;
-#if defined(AF_INET6)
+#if defined(KAFFE_INET6)
 	case 16:
 #if defined(BSD44)
 		sin6->sin6_len = sizeof(struct sockaddr_in6);
@@ -512,7 +512,7 @@
 	case 4:
 		family = AF_INET;
 		break;
-#if defined(AF_INET6)
+#if defined(KAFFE_INET6)
 	case 16:
 		family = AF_INET6;
 		break;
